Version semantic
=================

.. automodule:: drain_swamp.version_semantic
   :members:
   :undoc-members:
   :private-members:
   :exclude-members: CURRENT_ALIASES, CURRENT_ALIAS_DEFAULT, KINDS
   :platform: Unix
   :synopsis: Bridge between git, setuptools-scm, and setuptools
   :ignore-module-all:
